SubpackageLintPlugin class
The subpackage_lint analyzer plugin.
Registers the subpackage import rules and their quick fixes with the Dart
analysis server. The rules are opt-in: enable them under the diagnostics:
section of the consuming project's analysis_options.yaml.
- Inheritance
-
- Object
- Plugin
- SubpackageLintPlugin
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
PluginRegistry registry) → void -
Registers analysis rules, quick fixes, and assists.
override
-
shutDown(
) → FutureOr< void> -
inherited
-
start(
) → FutureOr< void> -
Initializes any necessary start-up state that is required for this plugin
to run.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited